@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -151,8 +151,8 @@ namespace {
             return result;
         }
 
-        NON_DEFAULT_CONSTRUCTABLE(Command);
-        NON_COPYABLE_NOR_MOVABLE(Command);
+        NON_DEFAULT_CONSTRUCTABLE(Command)
+        NON_COPYABLE_NOR_MOVABLE(Command)
 
     private:
         sys::Process::Builder intercept_;
