@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -244,7 +244,7 @@ namespace cs {
             Configuration result;
             ::cs::from_json(in, result);
 
-            return rust::Ok(result);
+            return rust::Ok(std::move(result));
         } catch (const std::exception &error) {
             return rust::Err(std::runtime_error(error.what()));
         }
