@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -36,10 +36,10 @@ namespace cs::semantic {
         explicit Build(Compilation cfg) noexcept;
 
         [[nodiscard]]
-        rust::Result<SemanticPtr> recognize(const rpc::Event &event);
+        rust::Result<SemanticPtr> recognize(const rpc::Event &event) const;
 
-        NON_DEFAULT_CONSTRUCTABLE(Build);
-        NON_COPYABLE_NOR_MOVABLE(Build);
+        NON_DEFAULT_CONSTRUCTABLE(Build)
+        NON_COPYABLE_NOR_MOVABLE(Build)
 
     private:
         std::shared_ptr<Tool> tools_;
