@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -33,7 +33,7 @@ namespace cs::semantic {
         if (this == &rhs)
             return true;
 
-        if (const auto* ptr = dynamic_cast<QueryCompiler const*>(&rhs); ptr != nullptr) {
+        if (const auto *const ptr = dynamic_cast<QueryCompiler const*>(&rhs); ptr != nullptr) {
             return true;
         }
         return false;
@@ -45,7 +45,7 @@ namespace cs::semantic {
     }
 
     std::list<cs::Entry> QueryCompiler::into_entries() const {
-        return std::list<cs::Entry>();
+        return {};
     }
 
     bool Preprocess::operator==(const Semantic &) const {
@@ -58,7 +58,7 @@ namespace cs::semantic {
     }
 
     std::list<cs::Entry> Preprocess::into_entries() const {
-        return std::list<cs::Entry>();
+        return {};
     }
 
     Compile::Compile(fs::path working_dir,
@@ -77,7 +77,7 @@ namespace cs::semantic {
         if (this == &rhs)
             return true;
 
-        if (const auto* ptr = dynamic_cast<Compile const*>(&rhs); ptr != nullptr) {
+        if (const auto *const ptr = dynamic_cast<Compile const*>(&rhs); ptr != nullptr) {
             return (working_dir == ptr->working_dir)
                 && (compiler == ptr->compiler)
                 && (output == ptr->output)
@@ -99,7 +99,18 @@ namespace cs::semantic {
 
     std::list<cs::Entry> Compile::into_entries() const {
         const auto abspath = [this](const fs::path &path) -> fs::path {
-            return (path.is_absolute()) ? path : working_dir / path;
+            auto candidate = (path.is_absolute()) ? path : working_dir / path;
+            // Create canonical path without checking of file existence.
+            fs::path result;
+            for (const auto& part : candidate) {
+                if (part == ".")
+                    continue;
+                if (part == "..")
+                    result = result.parent_path();
+                else
+                    result = result / part;
+            }
+            return result;
         };
         std::list<cs::Entry> results;
         for (const auto& source : sources) {
