@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -43,14 +43,5 @@ namespace domain {
     bool operator==(const Execution& lhs, const Execution& rhs);
     std::ostream& operator<<(std::ostream&, const Execution&);
 
-    struct Run {
-        Execution execution;
-        ProcessId pid = 0u;
-        ProcessId ppid = 0u;
-    };
-
-    bool operator==(const Run& lhs, const Run& rhs);
-    std::ostream& operator<<(std::ostream&, const Run&);
-
     using SessionLocator = std::string;
 }
