@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -42,9 +42,9 @@ namespace {
 
     rust::Result<ic::Execution> capture_execution(const flags::Arguments& args, sys::env::Vars &&environment)
     {
-        auto path = sys::os::get_path(environment);
+        const auto path = sys::os::get_path(environment);
 
-        auto command = args.as_string_list(cmd::intercept::FLAG_COMMAND)
+        const auto command = args.as_string_list(cmd::intercept::FLAG_COMMAND)
                 .and_then<std::vector<std::string_view>>([](auto args) {
                     using Result = rust::Result<std::vector<std::string_view>>;
                     return (args.empty())
@@ -52,7 +52,7 @@ namespace {
                             : Result(rust::Ok(args));
                 });
 
-        auto executable = rust::merge(path, command)
+        const auto executable = rust::merge(path, command)
                 .and_then<fs::path>([](auto tuple) {
                     const auto&[path, command] = tuple;
                     auto executable = command.front();
@@ -92,11 +92,11 @@ namespace ic {
         auto server = grpc::ServerBuilder()
                           .RegisterService(&supervisor)
                           .RegisterService(&interceptor)
-                          .AddListeningPort("127.0.0.1:0", grpc::InsecureServerCredentials(), &port)
+                          .AddListeningPort("dns:///localhost:0", grpc::InsecureServerCredentials(), &port)
                           .BuildAndStart();
 
         // Create session_locator URL for the services
-        auto session_locator = SessionLocator(fmt::format("127.0.0.1:{}", port));
+        auto session_locator = SessionLocator(fmt::format("dns:///localhost:{}", port));
         spdlog::debug("Running gRPC server. {0}", session_locator);
         // Execute the build command
         auto result = session_->run(execution_, session_locator);
@@ -125,9 +125,9 @@ namespace ic {
     }
 
     rust::Result<ps::CommandPtr> Application::command(const flags::Arguments &args, const char **envp) const {
-        auto execution = capture_execution(args, sys::env::from(envp));
-        auto session = Session::from(args, envp);
-        auto reporter = Reporter::from(args);
+        const auto execution = capture_execution(args, sys::env::from(envp));
+        const auto session = Session::from(args, envp);
+        const auto reporter = Reporter::from(args);
 
         return rust::merge(execution, session, reporter)
                 .map<ps::CommandPtr>([](auto tuple) {
