@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -43,7 +43,7 @@ namespace ic {
     { }
 
     void Reporter::report(const rpc::Event& event) {
-        std::lock_guard<std::mutex> lock(mutex_);
+        const std::lock_guard<std::mutex> lock(mutex_);
 
         database_->insert_event(event)
                 .on_error([](auto error) {
