@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -42,8 +42,8 @@ namespace ic {
 
         ~Reporter() noexcept = default;
 
-        NON_DEFAULT_CONSTRUCTABLE(Reporter);
-        NON_COPYABLE_NOR_MOVABLE(Reporter);
+        NON_DEFAULT_CONSTRUCTABLE(Reporter)
+        NON_COPYABLE_NOR_MOVABLE(Reporter)
 
     private:
         ic::collect::db::EventsDatabaseWriter::Ptr database_;
