@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -32,8 +32,8 @@ namespace ic {
         [[nodiscard]] rust::Result<ic::Execution> resolve(const ic::Execution &execution) const override;
         [[nodiscard]] sys::Process::Builder supervise(const ic::Execution &execution) const override;
 
-        NON_DEFAULT_CONSTRUCTABLE(LibraryPreloadSession);
-        NON_COPYABLE_NOR_MOVABLE(LibraryPreloadSession);
+        NON_DEFAULT_CONSTRUCTABLE(LibraryPreloadSession)
+        NON_COPYABLE_NOR_MOVABLE(LibraryPreloadSession)
 
     private:
         [[nodiscard]] std::map<std::string, std::string> update(const std::map<std::string, std::string>& env) const;
