@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -49,8 +49,8 @@ namespace el {
          */
         char const* store(char const* input) noexcept;
 
-        NON_DEFAULT_CONSTRUCTABLE(Buffer);
-        NON_COPYABLE_NOR_MOVABLE(Buffer);
+        NON_DEFAULT_CONSTRUCTABLE(Buffer)
+        NON_COPYABLE_NOR_MOVABLE(Buffer)
 
     private:
         char* top_;
