@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -17,7 +17,6 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
 #include "report/libexec/Resolver.h"
 
 #include "report/libexec/Array.h"
@@ -33,10 +32,8 @@
 
 namespace {
 
-    constexpr char DIR_SEPARATOR = '/';
-
     bool contains_dir_separator(std::string_view const &candidate) {
-        return std::find(candidate.begin(), candidate.end(), DIR_SEPARATOR) != candidate.end();
+        return std::find(candidate.begin(), candidate.end(), OS_DIR_SEPARATOR) != candidate.end();
     }
 }
 
@@ -63,13 +60,16 @@ namespace el {
         return rust::Err(ENOENT);
     }
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wvla"
+
     rust::Result<const char*, int> Resolver::from_path(std::string_view const &file, const char **envp) {
         if (contains_dir_separator(file)) {
             // the file contains a dir separator, it is treated as path.
             return from_current_directory(file);
         } else {
             // otherwise use the PATH variable to locate the executable.
-            const char *paths = el::env::get_env_value(envp, "PATH");
+            const char *const paths = el::env::get_env_value(envp, "PATH");
             if (paths != nullptr) {
                 return from_search_path(file, paths);
             }
@@ -85,13 +85,15 @@ namespace el {
         }
     }
 
+#pragma GCC diagnostic pop
+
     rust::Result<const char*, int> Resolver::from_search_path(std::string_view const &file, const char *search_path) {
         if (contains_dir_separator(file)) {
             // the file contains a dir separator, it is treated as path.
             return from_current_directory(file);
         } else {
             // otherwise use the given search path to locate the executable.
-            for (auto path : el::Paths(search_path)) {
+            for (const auto &path : el::Paths(search_path)) {
                 // ignore empty entries
                 if (path.empty()) {
                     continue;
@@ -106,7 +108,7 @@ namespace el {
                     char *const candidate_begin = candidate;
                     char *const candidate_end = candidate + PATH_MAX;
                     auto it = el::array::copy(path.begin(), path.end(), candidate_begin, candidate_end);
-                    *it++ = DIR_SEPARATOR;
+                    *it++ = OS_DIR_SEPARATOR;
                     it = el::array::copy(file.begin(), file.end(), it, candidate_end);
                     *it = 0;
                 }
