@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -53,7 +53,7 @@ namespace el {
         [[nodiscard]]
         virtual rust::Result<const char*, int> from_search_path(std::string_view const &file, const char *search_path);
 
-        NON_COPYABLE_NOR_MOVABLE(Resolver);
+        NON_COPYABLE_NOR_MOVABLE(Resolver)
 
     private:
         char result_[PATH_MAX];
