@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -77,7 +77,7 @@ namespace {
             const char** end = argv;
             while (*end != nullptr)
                 ++end;
-            return std::list<std::string>(argv, end);
+            return {argv, end};
         }
 
         rust::Result<wr::Execution> make_execution(const char **argv, sys::env::Vars &&environment) noexcept
