@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -33,8 +33,8 @@ namespace wr {
 
         [[nodiscard]] rust::Result<int> execute() const override;
 
-        NON_DEFAULT_CONSTRUCTABLE(Command);
-        NON_COPYABLE_NOR_MOVABLE(Command);
+        NON_DEFAULT_CONSTRUCTABLE(Command)
+        NON_COPYABLE_NOR_MOVABLE(Command)
 
     protected:
         wr::SessionLocator session_;
