@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -41,8 +41,8 @@ namespace wr {
         void report_start(ProcessId pid, const Execution &execution);
         void report_wait(sys::ExitStatus exit_status);
 
-        NON_DEFAULT_CONSTRUCTABLE(EventReporter);
-        NON_COPYABLE_NOR_MOVABLE(EventReporter);
+        NON_DEFAULT_CONSTRUCTABLE(EventReporter)
+        NON_COPYABLE_NOR_MOVABLE(EventReporter)
 
     private:
         EventFactory event_factory;
