@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -39,8 +39,8 @@ namespace wr {
 
         rust::Result<wr::Execution> resolve(const wr::Execution &);
 
-        NON_DEFAULT_CONSTRUCTABLE(SupervisorClient);
-        NON_COPYABLE_NOR_MOVABLE(SupervisorClient);
+        NON_DEFAULT_CONSTRUCTABLE(SupervisorClient)
+        NON_COPYABLE_NOR_MOVABLE(SupervisorClient)
 
     private:
         std::shared_ptr<::grpc::Channel> channel_;
@@ -53,8 +53,8 @@ namespace wr {
 
         rust::Result<int> report(const rpc::Event &);
 
-        NON_DEFAULT_CONSTRUCTABLE(InterceptorClient);
-        NON_COPYABLE_NOR_MOVABLE(InterceptorClient);
+        NON_DEFAULT_CONSTRUCTABLE(InterceptorClient)
+        NON_COPYABLE_NOR_MOVABLE(InterceptorClient)
 
     private:
         std::shared_ptr<::grpc::Channel> channel_;
