@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -28,6 +28,7 @@
 #include <string_view>
 #include <vector>
 #include <iosfwd>
+#include <optional>
 
 namespace flags {
 
@@ -52,7 +53,7 @@ namespace flags {
         [[nodiscard]] rust::Result<std::vector<std::string_view>> as_string_list(const std::string_view& key) const;
 
     public:
-        NON_DEFAULT_CONSTRUCTABLE(Arguments);
+        NON_DEFAULT_CONSTRUCTABLE(Arguments)
 
     private:
         using Parameter = std::vector<std::string_view>;
@@ -129,7 +130,7 @@ namespace flags {
         void print_version(std::ostream&) const;
 
     public:
-        NON_DEFAULT_CONSTRUCTABLE(Parser);
+        NON_DEFAULT_CONSTRUCTABLE(Parser)
 
     private:
         const std::string_view name_;
