@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -141,14 +141,14 @@ namespace flags {
     {
         if (auto values = parameters_.find(key); values != parameters_.end()) {
             return (values->second.size() == 1)
-                ? (rust::Ok(values->second.front()))
+                ? rust::Result<std::string_view>(
+                        rust::Ok(values->second.front()))
                 : rust::Result<std::string_view>(
-                    rust::Err(std::runtime_error(
-                        fmt::format("Parameter \"{0}\" is not a single string.", key))));
+                        rust::Err(std::runtime_error(
+                                fmt::format("Parameter \"{0}\" is not a single string.", key))));
         }
-        return rust::Result<std::string_view>(
-            rust::Err(std::runtime_error(
-                fmt::format("Parameter \"{0}\" is not available.", key))));
+        return rust::Err(std::runtime_error(
+                fmt::format("Parameter \"{0}\" is not available.", key)));
     }
 
     rust::Result<std::vector<std::string_view>> Arguments::as_string_list(const std::string_view& key) const
@@ -156,9 +156,8 @@ namespace flags {
         if (auto values = parameters_.find(key); values != parameters_.end()) {
             return rust::Ok(values->second);
         }
-        return rust::Result<std::vector<std::string_view>>(
-            rust::Err(std::runtime_error(
-                fmt::format("Parameter \"{0}\" is not available.", key))));
+        return rust::Err(std::runtime_error(
+                fmt::format("Parameter \"{0}\" is not available.", key)));
     }
 
     std::ostream& operator<<(std::ostream& os, const Arguments& args)
@@ -314,7 +313,7 @@ namespace flags {
             });
     }
 
-    void Parser::print_help(const Parser *sub_command, std::ostream& os) const {
+    void Parser::print_help(const Parser *const sub_command, std::ostream& os) const {
         print_usage(sub_command, os);
 
         const Parser &parser = (sub_command != nullptr) ? *sub_command : *this;
@@ -336,7 +335,7 @@ namespace flags {
         }
     }
 
-    void Parser::print_usage(const Parser *sub_command, std::ostream& os) const {
+    void Parser::print_usage(const Parser *const sub_command, std::ostream& os) const {
         os << "Usage: " << name_;
         // check for the given command
         if (sub_command != nullptr) {
