@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -35,7 +35,7 @@ namespace ps {
         virtual rust::Result<flags::Arguments> parse(int argc, const char** argv) const = 0;
         virtual rust::Result<CommandPtr> command(const flags::Arguments &args, const char** envp) const = 0;
 
-        NON_DEFAULT_CONSTRUCTABLE(ApplicationFromArgs);
+        NON_DEFAULT_CONSTRUCTABLE(ApplicationFromArgs)
 
     protected:
         ApplicationLogConfig log_config_;
