@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -52,8 +52,8 @@ namespace sys {
         bool is_exited() const;
 
     private:
-        bool is_code_;
-        int code_;
+        const bool is_code_;
+        const int code_;
     };
 
     class Process {
@@ -69,10 +69,10 @@ namespace sys {
     public:
         explicit Process(pid_t pid);
 
-        NON_DEFAULT_CONSTRUCTABLE(Process);
+        NON_DEFAULT_CONSTRUCTABLE(Process)
 
     private:
-        pid_t pid_;
+        const pid_t pid_;
     };
 
     class Process::Builder {
@@ -103,7 +103,7 @@ namespace sys {
 #endif
 
     public:
-        NON_DEFAULT_CONSTRUCTABLE(Builder);
+        NON_DEFAULT_CONSTRUCTABLE(Builder)
 
     private:
         fs::path program_;
