@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -32,8 +32,8 @@ namespace sys {
         ~SignalForwarder() noexcept;
 
     public:
-        NON_DEFAULT_CONSTRUCTABLE(SignalForwarder);
-        NON_COPYABLE_NOR_MOVABLE(SignalForwarder);
+        NON_DEFAULT_CONSTRUCTABLE(SignalForwarder)
+        NON_COPYABLE_NOR_MOVABLE(SignalForwarder)
 
     private:
         pid_t pid_;
