@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -34,12 +34,12 @@ namespace sys {
 #ifdef HAVE_STRERROR_R
 #if defined(__GLIBC__) && defined(_GNU_SOURCE)
         char buffer[256];
-        char* result = ::strerror_r(error, buffer, 255);
-        return std::string(result);
+        char *const result = ::strerror_r(error, buffer, 255);
+        return {result};
 #else
         char buffer[256];
         ::strerror_r(error, buffer, 255);
-        return std::string(buffer);
+        return {buffer};
 #endif
 #else
         return fmt::format("{0}", error);
