@@ -1,4 +1,4 @@
-/*  Copyright (C) 2012-2021 by László Nagy
+/*  Copyright (C) 2012-2022 by László Nagy
     This file is part of Bear.
 
     Bear is a tool to generate compilation database for clang tooling.
@@ -84,11 +84,10 @@ namespace {
             char* const argv[],
             char* const envp[])>;
 
-    rust::Result<spawn_function_t> reference_spawn_function()
+    spawn_function_t reference_spawn_function()
     {
-        spawn_function_t result = [](const char* path,
-                                     char* const argv[],
-                                     char* const envp[]) -> rust::Result<pid_t> {
+        return [](const char* path, char* const argv[], char* const envp[]) -> rust::Result<pid_t> {
+
             errno = 0;
             pid_t child;
             if (0 != ::posix_spawnp(&child, path, nullptr, nullptr, const_cast<char**>(argv), const_cast<char**>(envp))) {
@@ -98,15 +97,12 @@ namespace {
                 return rust::Ok(child);
             }
         };
-        return rust::Ok(result);
     }
 
 #ifdef SUPPORT_PRELOAD
-    rust::Result<spawn_function_t> resolve_spawn_function()
+    spawn_function_t resolve_spawn_function()
     {
-        spawn_function_t fp = [](const char* path,
-                                 char* const argv[],
-                                 char* const envp[]) -> rust::Result<pid_t> {
+        return [](const char* path, char* const argv[], char* const envp[]) -> rust::Result<pid_t> {
 
             void *handle = ::dlopen(LIBC_SO, RTLD_LAZY);
             if (handle == nullptr) {
@@ -133,7 +129,6 @@ namespace {
                 return rust::Ok(child);
             }
         };
-        return rust::Ok(fp);
     }
 #endif
 
@@ -171,7 +166,7 @@ namespace {
                 });
     }
 
-    rust::Result<sys::ExitStatus> wait_for(pid_t pid, bool request_for_signals)
+    rust::Result<sys::ExitStatus> wait_for(const pid_t pid, const bool request_for_signals)
     {
         errno = 0;
         const int mask = request_for_signals ? (WUNTRACED | WCONTINUED) : 0;
@@ -193,7 +188,7 @@ namespace {
         }
     }
 
-    rust::Result<int> send_signal(pid_t pid, int num)
+    rust::Result<int> send_signal(const pid_t pid, const int num)
     {
         errno = 0;
         if (const int result = ::kill(pid, num); 0 == result) {
@@ -243,7 +238,7 @@ namespace sys {
         return pid_;
     }
 
-    rust::Result<ExitStatus> Process::wait(bool request_for_signals)
+    rust::Result<ExitStatus> Process::wait(const bool request_for_signals)
     {
         spdlog::debug("Process wait requested. [pid: {}]", pid_);
         return wait_for(pid_, request_for_signals)
@@ -306,19 +301,15 @@ namespace sys {
 
     rust::Result<Process> Process::Builder::spawn()
     {
-        return reference_spawn_function()
-            .and_then<Process>([this](auto fp) {
-                return spawn_process(fp, program_, parameters_, environment_);
-            });
+        auto fp = reference_spawn_function();
+        return spawn_process(fp, program_, parameters_, environment_);
     }
 
 #ifdef SUPPORT_PRELOAD
     rust::Result<Process> Process::Builder::spawn_with_preload()
     {
-        return resolve_spawn_function()
-            .and_then<Process>([this](auto fp) {
-                return spawn_process(fp, program_, parameters_, environment_);
-            });
+        auto fp = resolve_spawn_function();
+        return spawn_process(fp, program_, parameters_, environment_);
     }
 #endif
 }
